Skip to main contentCrate screaming_float
Source - ScreamingNanChecker
- Like
noisy_float’s NumChecker, except it plays the
Wilhelm Scream instead of panicking.
- s32
- Shorthand for
S32::new(value). - s64
- Shorthand for
S64::new(value).
- S32
- A floating point number behaving like
f32 that screams when it is constructed from a NaN. - S64
- A floating point number behaving like
f64 that screams when it is constructed from a NaN.